@@ -41,7 +41,8 @@ func New(pbm *pbm.PBM) *Agent {
 	}
 }
 
-func (a *Agent) AddNode(ctx context.Context, curi string, dumpConns int) (err error) {
+func (a *Agent) AddNode(ctx context.Context, curi string, dumpConns int) error {
+	var err error
 	a.node, err = pbm.NewNode(ctx, curi, dumpConns)
 	return err
 }
@@ -67,12 +68,20 @@ func (a *Agent) CanStart() error {
 		return errors.New("mongos is not supported")
 	}
 
+	ver, err := pbm.GetMongoVersion(context.Background(), a.pbm.Conn)
+	if err != nil {
+		return errors.WithMessage(err, "get mongo version")
+	}
+	if err := pbm.FeatureSupport(ver).PBMSupport(); err != nil {
+		a.log.Warning("", "", "", primitive.Timestamp{}, "WARNING: %v", err)
+	}
+
 	return nil
 }
 
 // Start starts listening the commands stream.
 func (a *Agent) Start() error {
-	a.log.Printf("pbm-agent:\n%s", version.DefaultInfo.All(""))
+	a.log.Printf("pbm-agent:\n%s", version.Current().All(""))
 	a.log.Printf("node: %s", a.node.ID())
 
 	c, cerr := a.pbm.ListenCmd(a.closeCMD)
@@ -122,14 +131,12 @@ func (a *Agent) Start() error {
 				return nil
 			}
 
-			switch err.(type) {
-			case pbm.ErrorCursor:
-				return errors.Wrap(err, "stop listening")
-			default:
-				ep, _ := a.pbm.GetEpoch()
-
-				a.log.Error("", "", "", ep.TS(), "listening commands: %v", err)
+			if errors.Is(err, pbm.CursorClosedError{}) {
+				return errors.WithMessage(err, "stop listening")
 			}
+
+			ep, _ := a.pbm.GetEpoch()
+			a.log.Error("", "", "", ep.TS(), "listening commands: %v", err)
 		}
 	}
 }
@@ -174,8 +181,7 @@ func (a *Agent) Delete(d *pbm.DeleteBackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 		return
 	}
 	defer func() {
-		err := lock.Release()
-		if err != nil {
+		if err := lock.Release(); err != nil {
 			l.Error("release lock: %v", err)
 		}
 	}()
@@ -247,8 +253,7 @@ func (a *Agent) DeletePITR(d *pbm.DeletePITRCmd, opid pbm.OPID, ep pbm.Epoch) {
 		return
 	}
 	defer func() {
-		err := lock.Release()
-		if err != nil {
+		if err := lock.Release(); err != nil {
 			l.Error("release lock: %v", err)
 		}
 	}()
@@ -397,8 +402,7 @@ func (a *Agent) Resync(opid pbm.OPID, ep pbm.Epoch) {
 	}
 
 	defer func() {
-		err = lock.Release()
-		if err != nil {
+		if err := lock.Release(); err != nil {
 			l.Error("reslase lock %v: %v", lock, err)
 		}
 	}()
@@ -424,40 +428,43 @@ type lockAquireFn func() (bool, error)
 
 // acquireLock tries to acquire the lock. If there is a stale lock
 // it tries to mark op that held the lock (backup, [pitr]restore) as failed.
-func (a *Agent) acquireLock(l *pbm.Lock, lg *log.Event, acquireFn lockAquireFn) (got bool, err error) {
+func (a *Agent) acquireLock(l *pbm.Lock, lg *log.Event, acquireFn lockAquireFn) (bool, error) {
 	if acquireFn == nil {
 		acquireFn = l.Acquire
 	}
 
-	got, err = acquireFn()
+	got, err := acquireFn()
 	if err == nil {
 		return got, nil
 	}
 
-	switch err := err.(type) {
-	case pbm.ErrDuplicateOp, pbm.ErrConcurrentOp:
+	if errors.Is(err, pbm.DuplicatedOpError{}) || errors.Is(err, pbm.ConcurrentOpError{}) {
 		lg.Debug("get lock: %v", err)
 		return false, nil
-	case pbm.ErrWasStaleLock:
-		lk := err.Lock
-		lg.Debug("stale lock: %v", lk)
-		var fn func(opid string) error
-		switch lk.Type {
-		case pbm.CmdBackup:
-			fn = a.pbm.MarkBcpStale
-		case pbm.CmdRestore:
-			fn = a.pbm.MarkRestoreStale
-		default:
-			return acquireFn()
-		}
-		merr := fn(lk.OPID)
-		if merr != nil {
-			lg.Warning("failed to mark stale op '%s' as failed: %v", lk.OPID, merr)
-		}
-		return acquireFn()
-	default:
+	}
+
+	var er pbm.StaleLockError
+	if !errors.As(err, &er) {
 		return false, err
 	}
+
+	lock := er.Lock
+	lg.Debug("stale lock: %v", lock)
+	var fn func(opid string) error
+	switch lock.Type {
+	case pbm.CmdBackup:
+		fn = a.pbm.MarkBcpStale
+	case pbm.CmdRestore:
+		fn = a.pbm.MarkRestoreStale
+	default:
+		return acquireFn()
+	}
+
+	if err := fn(lock.OPID); err != nil {
+		lg.Warning("failed to mark stale op '%s' as failed: %v", lock.OPID, err)
+	}
+
+	return acquireFn()
 }
 
 func (a *Agent) HbPause() {
@@ -473,13 +480,22 @@ func (a *Agent) HbIsRun() bool {
 }
 
 func (a *Agent) HbStatus() {
+	l := a.log.NewEvent("agentCheckup", "", "", primitive.Timestamp{})
+
+	nodeVersion, err := a.node.GetMongoVersion()
+	if err != nil {
+		l.Error("get mongo version: %v", err)
+	}
+
 	hb := pbm.AgentStat{
-		Node: a.node.Name(),
-		RS:   a.node.RS(),
-		Ver:  version.DefaultInfo.Version,
+		Node:       a.node.Name(),
+		RS:         a.node.RS(),
+		AgentVer:   version.Current().Version,
+		MongoVer:   nodeVersion.VersionString,
+		PerconaVer: nodeVersion.PSMDBVersion,
 	}
 	defer func() {
-		if err := a.pbm.RmAgentStatus(hb); err != nil {
+		if err := a.pbm.RemoveAgentStatus(hb); err != nil {
 			logger := a.log.NewEvent("agentCheckup", "", "", primitive.Timestamp{})
 			logger.Error("remove agent heartbeat: %v", err)
 		}
@@ -488,12 +504,9 @@ func (a *Agent) HbStatus() {
 	tk := time.NewTicker(pbm.AgentsStatCheckRange)
 	defer tk.Stop()
 
-	l := a.log.NewEvent("agentCheckup", "", "", primitive.Timestamp{})
-
 	// check storage once in a while if all is ok (see https://jira.percona.com/browse/PBM-647)
 	const checkStoreIn = int(60 / (pbm.AgentsStatCheckRange / time.Second))
-	var cc int
-
+	cc := 0
 	for range tk.C {
 		// don't check if on pause (e.g. physical restore)
 		if !a.HbIsRun() {
@@ -537,6 +550,7 @@ func (a *Agent) HbStatus() {
 			hb.Hidden = inf.Hidden
 			hb.Passive = inf.Passive
 		}
+		hb.Arbiter = inf.ArbiterOnly
 
 		err = a.pbm.SetAgentStatus(hb)
 		if err != nil {
@@ -545,33 +559,25 @@ func (a *Agent) HbStatus() {
 	}
 }
 
-func (a *Agent) pbmStatus() (sts pbm.SubsysStatus) {
+func (a *Agent) pbmStatus() pbm.SubsysStatus {
 	err := a.pbm.Conn.Ping(a.pbm.Context(), nil)
 	if err != nil {
-		sts.OK = false
-		sts.Err = err.Error()
-		return
+		return pbm.SubsysStatus{Err: err.Error()}
 	}
 
-	sts.OK = true
-	return
+	return pbm.SubsysStatus{OK: true}
 }
 
-func (a *Agent) nodeStatus() (sts pbm.SubsysStatus) {
+func (a *Agent) nodeStatus() pbm.SubsysStatus {
 	err := a.node.Session().Ping(a.pbm.Context(), nil)
 	if err != nil {
-		sts.OK = false
-		sts.Err = err.Error()
-		return
+		return pbm.SubsysStatus{Err: err.Error()}
 	}
 
-	sts.OK = true
-	return
+	return pbm.SubsysStatus{OK: true}
 }
 
-func (a *Agent) storStatus(log *log.Event, forceCheckStorage bool) (sts pbm.SubsysStatus) {
-	sts.OK = false
-
+func (a *Agent) storStatus(log *log.Event, forceCheckStorage bool) pbm.SubsysStatus {
 	// check storage once in a while if all is ok (see https://jira.percona.com/browse/PBM-647)
 	// but if storage was(is) failed, check it always
 	stat, err := a.pbm.GetAgentStatus(a.node.RS(), a.node.Name())
@@ -579,31 +585,27 @@ func (a *Agent) storStatus(log *log.Event, forceCheckStorage bool) (sts pbm.Subs
 		log.Warning("get current storage status: %v", err)
 	}
 	if !forceCheckStorage && stat.StorageStatus.OK {
-
-		sts.OK = true
-		return sts
+		return pbm.SubsysStatus{OK: true}
 	}
 
 	stg, err := a.pbm.GetStorage(log)
 	if err != nil {
-		sts.Err = fmt.Sprintf("unable to get storage: %v", err)
-		return sts
+		return pbm.SubsysStatus{Err: fmt.Sprintf("unable to get storage: %v", err)}
 	}
 
 	_, err = stg.FileStat(pbm.StorInitFile)
 	if errors.Is(err, storage.ErrNotExist) {
-		err := stg.Save(pbm.StorInitFile, bytes.NewBufferString(version.DefaultInfo.Version), 0)
+		err := stg.Save(pbm.StorInitFile, bytes.NewBufferString(version.Current().Version), 0)
 		if err != nil {
-			sts.Err = fmt.Sprintf("storage: no init file, attempt to create failed: %v", err)
-			return sts
+			return pbm.SubsysStatus{
+				Err: fmt.Sprintf("storage: no init file, attempt to create failed: %v", err),
+			}
 		}
 	} else if err != nil {
-		sts.Err = fmt.Sprintf("storage check failed with: %v", err)
-		return sts
+		return pbm.SubsysStatus{Err: fmt.Sprintf("storage check failed with: %v", err)}
 	}
 
-	sts.OK = true
-	return sts
+	return pbm.SubsysStatus{OK: true}
 }
 
 func logHbStatus(name string, st pbm.SubsysStatus, l *log.Event) {
