@@ -17,7 +17,7 @@ type currentBackup struct {
 	cancel context.CancelFunc
 }
 
-func (a *Agent) setBcp(b *currentBackup) (changed bool) {
+func (a *Agent) setBcp(b *currentBackup) bool {
 	a.mx.Lock()
 	defer a.mx.Unlock()
 	if a.bcp != nil {
@@ -61,20 +61,25 @@ func (a *Agent) Backup(cmd *pbm.BackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 		return
 	}
 	if nodeInfo.IsStandalone() {
-		l.Error("mongod node can not be used to fetch a consistent backup because it has no oplog. Please restart it as a primary in a single-node replicaset to make it compatible with PBM's backup method using the oplog")
+		l.Error("mongod node can not be used to fetch a consistent backup because it has no oplog. " +
+			"Please restart it as a primary in a single-node replicaset " +
+			"to make it compatible with PBM's backup method using the oplog")
 		return
 	}
 
-	q, err := backup.NodeSuits(a.node, nodeInfo)
+	isClusterLeader := nodeInfo.IsClusterLeader()
+	canRunBackup, err := backup.NodeSuitsExt(a.node, nodeInfo, cmd.Type)
 	if err != nil {
 		l.Error("node check: %v", err)
-		return
+		if !isClusterLeader {
+			return
+		}
 	}
-
-	// node is not suitable for doing backup
-	if !q {
+	if !canRunBackup {
 		l.Info("node is not suitable for backup")
-		return
+		if !isClusterLeader {
+			return
+		}
 	}
 
 	// wakeup the slicer not to wait for the tick
@@ -83,7 +88,6 @@ func (a *Agent) Backup(cmd *pbm.BackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 	}
 
 	var bcp *backup.Backup
-
 	switch cmd.Type {
 	case pbm.PhysicalBackup:
 		bcp = backup.NewPhysical(a.pbm, a.node)
@@ -108,7 +112,7 @@ func (a *Agent) Backup(cmd *pbm.BackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 	}
 	bcp.SetTimeouts(cfg.Backup.Timeouts)
 
-	if nodeInfo.IsClusterLeader() {
+	if isClusterLeader {
 		balancer := pbm.BalancerModeOff
 		if nodeInfo.IsSharded() {
 			bs, err := a.pbm.GetBalancerStatus()
@@ -127,6 +131,12 @@ func (a *Agent) Backup(cmd *pbm.BackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 		}
 		l.Debug("init backup meta")
 
+		if err = pbm.CheckTopoForBackup(a.pbm, cmd.Type); err != nil {
+			ferr := a.pbm.ChangeBackupState(cmd.Name, pbm.StatusError, err.Error())
+			l.Info("mark backup as %s `%v`: %v", pbm.StatusError, err, ferr)
+			return
+		}
+
 		// Incremental backup history is stored by WiredTiger on the node
 		// not replset. So an `incremental && not_base` backup should land on
 		// the agent that made a previous (src) backup.
@@ -144,7 +154,23 @@ func (a *Agent) Backup(cmd *pbm.BackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 				}
 			}
 		}
-		nodes, err := a.pbm.BcpNodesPriority(c)
+
+		agents, err := a.pbm.ListAgentStatuses()
+		if err != nil {
+			l.Error("get agents list: %v", err)
+			return
+		}
+
+		validCandidates := make([]pbm.AgentStat, 0, len(agents))
+		for _, s := range agents {
+			if pbm.FeatureSupport(s.MongoVersion()).BackupType(cmd.Type) != nil {
+				continue
+			}
+
+			validCandidates = append(validCandidates, s)
+		}
+
+		nodes, err := a.pbm.BcpNodesPriority(c, validCandidates)
 		if err != nil {
 			l.Error("get nodes priority: %v", err)
 			return
@@ -240,7 +266,7 @@ func (a *Agent) nominateRS(bcp, rs string, nodes [][]string, l *log.Event) error
 
 	for _, n := range nodes {
 		nms, err := a.pbm.GetRSNominees(bcp, rs)
-		if err != nil && err != pbm.ErrNotFound {
+		if err != nil && !errors.Is(err, pbm.ErrNotFound) {
 			return errors.Wrap(err, "get nomination meta")
 		}
 		if nms != nil && len(nms.Ack) > 0 {
@@ -265,9 +291,10 @@ func (a *Agent) nominateRS(bcp, rs string, nodes [][]string, l *log.Event) error
 	return nil
 }
 
-func (a *Agent) waitNomination(bcp, rs, node string, l *log.Event) (got bool, err error) {
+func (a *Agent) waitNomination(bcp, rs, node string, l *log.Event) (bool, error) {
 	tk := time.NewTicker(time.Millisecond * 500)
 	defer tk.Stop()
+
 	stop := time.NewTimer(pbm.WaitActionStart)
 	defer stop.Stop()
 
