@@ -12,6 +12,7 @@ import (
 	"go.mongodb.org/mongo-driver/bson/primitive"
 
 	"github.com/percona/percona-backup-mongodb/pbm"
+	"github.com/percona/percona-backup-mongodb/pbm/sel"
 )
 
 type deleteBcpOpts struct {
@@ -21,14 +22,12 @@ type deleteBcpOpts struct {
 }
 
 func deleteBackup(pbmClient *pbm.PBM, d *deleteBcpOpts, outf outFormat) (fmt.Stringer, error) {
-	if !d.force && isTTY() {
-		fmt.Print("Are you sure you want delete backup(s)? [y/N] ")
-		scanner := bufio.NewScanner(os.Stdin)
-		scanner.Scan()
-		switch strings.TrimSpace(scanner.Text()) {
-		case "yes", "Yes", "YES", "Y", "y":
-		default:
-			return nil, nil
+	if !d.force {
+		if err := askConfirmation("Are you sure you want to delete backup(s)?"); err != nil {
+			if errors.Is(err, errUserCanceled) {
+				return outMsg{err.Error()}, nil
+			}
+			return nil, err
 		}
 	}
 
@@ -63,7 +62,7 @@ func deleteBackup(pbmClient *pbm.PBM, d *deleteBcpOpts, outf outFormat) (fmt.Str
 			Type: pbm.CmdDeleteBackup,
 		},
 		time.Second*60)
-	if err != nil && err != errTout {
+	if err != nil && !errors.Is(err, errTout) {
 		return nil, err
 	}
 
@@ -76,7 +75,7 @@ func deleteBackup(pbmClient *pbm.PBM, d *deleteBcpOpts, outf outFormat) (fmt.Str
 		return nil, errors.New(errl)
 	}
 
-	if err == errTout {
+	if errors.Is(err, errTout) {
 		fmt.Println("\nOperation is still in progress, please check status in a while")
 	} else {
 		time.Sleep(time.Second)
@@ -99,18 +98,16 @@ func deletePITR(pbmClient *pbm.PBM, d *deletePitrOpts, outf outFormat) (fmt.Stri
 		return nil, errors.New("either --older-than or --all should be set")
 	}
 
-	if !d.force && isTTY() {
-		all := ""
+	if !d.force {
+		q := "Are you sure you want to delete chunks?"
 		if d.all {
-			all = " ALL"
+			q = "Are you sure you want to delete ALL chunks?"
 		}
-		fmt.Printf("Are you sure you want delete%s chunks? [y/N] ", all)
-		scanner := bufio.NewScanner(os.Stdin)
-		scanner.Scan()
-		switch strings.TrimSpace(scanner.Text()) {
-		case "yes", "Yes", "YES", "Y", "y":
-		default:
-			return nil, nil
+		if err := askConfirmation(q); err != nil {
+			if errors.Is(err, errUserCanceled) {
+				return outMsg{err.Error()}, nil
+			}
+			return nil, err
 		}
 	}
 
@@ -140,7 +137,7 @@ func deletePITR(pbmClient *pbm.PBM, d *deletePitrOpts, outf outFormat) (fmt.Stri
 			Type: pbm.CmdDeletePITR,
 		},
 		time.Second*60)
-	if err != nil && err != errTout {
+	if err != nil && !errors.Is(err, errTout) {
 		return nil, err
 	}
 
@@ -153,7 +150,7 @@ func deletePITR(pbmClient *pbm.PBM, d *deletePitrOpts, outf outFormat) (fmt.Stri
 		return nil, errors.New(errl)
 	}
 
-	if err == errTout {
+	if errors.Is(err, errTout) {
 		fmt.Println("\nOperation is still in progress, please check status in a while")
 	} else {
 		time.Sleep(time.Second)
@@ -192,13 +189,12 @@ func retentionCleanup(pbmClient *pbm.PBM, d *cleanupOptions) (fmt.Stringer, erro
 	}
 
 	if !d.yes {
-		yes, err := askCleanupConfirmation(info)
-		if err != nil {
+		if err := askCleanupConfirmation(info); err != nil {
+			if errors.Is(err, errUserCanceled) {
+				return outMsg{err.Error()}, nil
+			}
 			return nil, err
 		}
-		if !yes {
-			return outMsg{"aborted"}, nil
-		}
 	}
 
 	tsop := time.Now().Unix()
@@ -280,13 +276,12 @@ func printCleanupInfoTo(w io.Writer, backups []pbm.BackupMeta, chunks []pbm.Oplo
 		fmt.Fprintln(w, "Snapshots:")
 		for i := range backups {
 			bcp := &backups[i]
-			t := bcp.Type
-			if len(bcp.Namespaces) != 0 {
+			t := string(bcp.Type)
+			if sel.IsSelective(bcp.Namespaces) {
 				t += ", selective"
 			} else if bcp.Type == pbm.IncrementalBackup && bcp.SrcBackup == "" {
 				t += ", base"
 			}
-
 			fmt.Fprintf(w, " - %s <%s> [restore_time: %s]\n",
 				bcp.Name, t, fmtTS(int64(bcp.LastWriteTS.T)))
 		}
@@ -328,21 +323,34 @@ func printCleanupInfoTo(w io.Writer, backups []pbm.BackupMeta, chunks []pbm.Oplo
 	}
 }
 
-func askCleanupConfirmation(info pbm.CleanupInfo) (bool, error) {
+func askCleanupConfirmation(info pbm.CleanupInfo) error {
 	printCleanupInfoTo(os.Stdout, info.Backups, info.Chunks)
+	return askConfirmation("Are you sure you want to delete?")
+}
 
-	if !isTTY() {
-		return false, errors.New("no tty")
+var errUserCanceled = errors.New("canceled")
+
+func askConfirmation(question string) error {
+	fi, err := os.Stdin.Stat()
+	if err != nil {
+		return errors.WithMessage(err, "stat stdin")
+	}
+	if (fi.Mode() & os.ModeCharDevice) == 0 {
+		return errors.New("no tty")
 	}
 
-	fmt.Print("Are you sure you want delete? [y/N] ")
+	fmt.Printf("%s [y/N] ", question)
 
 	scanner := bufio.NewScanner(os.Stdin)
 	scanner.Scan()
-	switch strings.TrimSpace(scanner.Text()) {
-	case "yes", "Yes", "YES", "Y", "y":
-		return true, nil
+	if err := scanner.Err(); err != nil {
+		return errors.WithMessage(err, "read stdin")
 	}
 
-	return false, nil
+	switch strings.TrimSpace(scanner.Text()) {
+	case "yes", "Yes", "YES", "Y", "y":
+		return nil
+	}
+
+	return errUserCanceled
 }
