@@ -34,7 +34,8 @@ type statusOut struct {
 	pretty bool
 }
 
-func (o statusOut) String() (s string) {
+func (o statusOut) String() string {
+	s := ""
 	for _, sc := range o.data {
 		if sc.Obj != nil {
 			s += sc.String() + "\n"
@@ -69,13 +70,14 @@ func (f statusSect) String() string {
 	return fmt.Sprintf("%s\n%s\n", sprinth(f.longName), f.Obj)
 }
 
-func (s statusOut) set(cn *pbm.PBM, curi string, sfilter map[string]bool) (err error) {
-	for _, se := range s.data {
+func (o statusOut) set(cn *pbm.PBM, sfilter map[string]bool) error {
+	for _, se := range o.data {
 		if sfilter != nil && !sfilter[se.Name] {
 			se.Obj = nil
 			continue
 		}
 
+		var err error
 		se.Obj, err = se.f(cn)
 		if err != nil {
 			return errors.Wrapf(err, "get status of %s", se.Name)
@@ -118,7 +120,7 @@ func status(cn *pbm.PBM, curi string, opts statusOptions, pretty bool) (fmt.Stri
 		}
 	}
 
-	err = out.set(cn, curi, sfilter)
+	err = out.set(cn, sfilter)
 
 	return out, err
 }
@@ -176,7 +178,7 @@ type node struct {
 	Errs []string `json:"errors,omitempty"`
 }
 
-func (n node) String() (s string) {
+func (n node) String() string {
 	if n.Role == RoleArbiter {
 		return fmt.Sprintf("%s [!Arbiter]: arbiter node is not supported", n.Host)
 	}
@@ -186,7 +188,7 @@ func (n node) String() (s string) {
 		role = RoleSecondary
 	}
 
-	s += fmt.Sprintf("%s [%s]: pbm-agent %v", n.Host, role, n.Ver)
+	s := fmt.Sprintf("%s [%s]: pbm-agent %v", n.Host, role, n.Ver)
 	if n.OK {
 		s += " OK"
 		return s
@@ -199,7 +201,8 @@ func (n node) String() (s string) {
 	return s
 }
 
-func (c cluster) String() (s string) {
+func (c cluster) String() string {
+	s := ""
 	for _, rs := range c {
 		s += fmt.Sprintf("%s:\n", rs.Name)
 		for _, n := range rs.Nodes {
@@ -228,19 +231,19 @@ func clusterStatus(cn *pbm.PBM, uri string) (fmt.Stringer, error) {
 		c := c
 
 		eg.Go(func() error {
-			rconn, err := connect(ctx, uri, c.Host)
+			client, err := connect(ctx, uri, c.Host)
 			if err != nil {
 				return errors.Wrapf(err, "connect to `%s` [%s]", c.RS, c.Host)
 			}
 
-			rsConfig, err := pbm.GetReplSetConfig(ctx, rconn)
+			rsConfig, err := pbm.GetReplSetConfig(ctx, client)
 			if err != nil {
-				rconn.Disconnect(ctx)
+				_ = client.Disconnect(ctx)
 				return errors.Wrapf(err, "get replset status for `%s`", c.RS)
 			}
-			info, err := pbm.GetNodeInfo(ctx, rconn)
+			info, err := pbm.GetNodeInfo(ctx, client)
 			// don't need the connection anymore despite the result
-			rconn.Disconnect(ctx)
+			_ = client.Disconnect(ctx)
 			if err != nil {
 				return errors.WithMessage(err, "get node info")
 			}
@@ -273,7 +276,7 @@ func clusterStatus(cn *pbm.PBM, uri string) (fmt.Stringer, error) {
 					nd.Errs = append(nd.Errs, fmt.Sprintf("ERROR: lost agent, last heartbeat: %v", stat.Heartbeat.T))
 					continue
 				}
-				nd.Ver = "v" + stat.Ver
+				nd.Ver = "v" + stat.AgentVer
 				nd.OK, nd.Errs = stat.OK()
 			}
 
@@ -302,7 +305,8 @@ func connect(ctx context.Context, uri, hosts string) (*mongo.Client, error) {
 		return nil, errors.Wrapf(err, "parse mongo-uri '%s'", uri)
 	}
 
-	// Preserving the `replicaSet` parameter will cause an error while connecting to the ConfigServer (mismatched replicaset names)
+	// Preserving the `replicaSet` parameter will cause an error
+	// while connecting to the ConfigServer (mismatched replicaset names)
 	query := curi.Query()
 	query.Del("replicaSet")
 	curi.RawQuery = query.Encode()
@@ -470,7 +474,7 @@ func getCurrOps(cn *pbm.PBM) (fmt.Stringer, error) {
 	}
 
 	// reaching here means no conflict operation, hence all locks are the same,
-	// hence any lock in `lk` contais info on the current op
+	// hence any lock in `lk` contains info on the current op
 	switch r.Type {
 	case pbm.CmdBackup:
 		bcp, err := cn.GetBackupByOPID(r.OPID)
@@ -531,33 +535,31 @@ func (s storageStat) String() string {
 		return a.RestoreTS > b.RestoreTS
 	})
 
-	for _, sn := range s.Snapshot {
+	for i := range s.Snapshot {
+		ss := &s.Snapshot[i]
 		var status string
-		switch sn.Status {
+		switch ss.Status {
 		case pbm.StatusDone:
-			status = fmt.Sprintf("[restore_to_time: %s]", fmtTS(sn.RestoreTS))
+			status = fmt.Sprintf("[restore_to_time: %s]", fmtTS(ss.RestoreTS))
 		case pbm.StatusCancelled:
-			status = fmt.Sprintf("[!canceled: %s]", fmtTS(sn.RestoreTS))
+			status = fmt.Sprintf("[!canceled: %s]", fmtTS(ss.RestoreTS))
 		case pbm.StatusError:
-			if errors.Is(sn.Err, errIncompatible) {
-				status = fmt.Sprintf("[incompatible: %s] [%s]", sn.Err.Error(), fmtTS(sn.RestoreTS))
+			if errors.Is(ss.Err, errIncompatible) {
+				status = fmt.Sprintf("[incompatible: %s] [%s]", ss.Err.Error(), fmtTS(ss.RestoreTS))
 			} else {
-				status = fmt.Sprintf("[ERROR: %s] [%s]", sn.Err.Error(), fmtTS(sn.RestoreTS))
+				status = fmt.Sprintf("[ERROR: %s] [%s]", ss.Err.Error(), fmtTS(ss.RestoreTS))
 			}
 		default:
-			status = fmt.Sprintf("[running: %s / %s]", sn.Status, fmtTS(sn.RestoreTS))
+			status = fmt.Sprintf("[running: %s / %s]", ss.Status, fmtTS(ss.RestoreTS))
 		}
 
-		kind := string(sn.Type)
-		if len(sn.Namespaces) != 0 {
-			kind += ", selective"
+		t := string(ss.Type)
+		if sel.IsSelective(ss.Namespaces) {
+			t += ", selective"
+		} else if ss.Type == pbm.IncrementalBackup && ss.SrcBackup == "" {
+			t += ", base"
 		}
-		if sn.Type == pbm.IncrementalBackup && sn.SrcBackup == "" {
-			kind += ", base"
-		}
-
-		ret += fmt.Sprintf("    %s %s <%s> %s\n",
-			sn.Name, fmtSize(sn.Size), kind, status)
+		ret += fmt.Sprintf("    %s %s <%s> %s\n", ss.Name, fmtSize(ss.Size), t, status)
 	}
 
 	if len(s.PITR.Ranges) == 0 {
@@ -672,6 +674,7 @@ func getStorageStat(cn *pbm.PBM, rsMap map[string]string) (fmt.Stringer, error)
 			}
 		}
 
+		bcp := bcp
 		snpsht.Size, err = getBackupSize(&bcp, stg)
 		if err != nil {
 			snpsht.Err = err
@@ -682,7 +685,7 @@ func getStorageStat(cn *pbm.PBM, rsMap map[string]string) (fmt.Stringer, error)
 		s.Snapshot = append(s.Snapshot, snpsht)
 	}
 
-	s.PITR, err = getPITRranges(cn, stg, bcps, rsMap)
+	s.PITR, err = getPITRranges(cn, bcps, rsMap)
 	if err != nil {
 		return s, errors.Wrap(err, "get PITR chunks")
 	}
@@ -690,7 +693,7 @@ func getStorageStat(cn *pbm.PBM, rsMap map[string]string) (fmt.Stringer, error)
 	return s, nil
 }
 
-func getPITRranges(cn *pbm.PBM, stg storage.Storage, bcps []pbm.BackupMeta, rsMap map[string]string) (*pitrRanges, error) {
+func getPITRranges(cn *pbm.PBM, bcps []pbm.BackupMeta, rsMap map[string]string) (*pitrRanges, error) {
 	shards, err := cn.ClusterMembers()
 	if err != nil {
 		return nil, errors.Wrap(err, "get cluster members")
@@ -726,7 +729,7 @@ func getPITRranges(cn *pbm.PBM, stg storage.Storage, bcps []pbm.BackupMeta, rsMa
 
 	var pr []pitrRange
 	for _, tl := range pbm.MergeTimelines(rstlines...) {
-		var bcplastWrite *primitive.Timestamp
+		var bcplastWrite primitive.Timestamp
 
 		for i := range bcps {
 			bcp := &bcps[i]
@@ -738,7 +741,7 @@ func getPITRranges(cn *pbm.PBM, stg storage.Storage, bcps []pbm.BackupMeta, rsMa
 				continue
 			}
 
-			bcplastWrite = &bcp.LastWriteTS
+			bcplastWrite = bcp.LastWriteTS
 			break
 		}
 
@@ -758,10 +761,10 @@ func isValidBaseSnapshot(bcp *pbm.BackupMeta) bool {
 		return true
 	}
 
-	switch err.(type) {
-	case errMissedReplsets, errIncompatibleFCVVersion:
+	switch {
+	case errors.Is(err, missedReplsetsError{}), errors.Is(err, incompatibleFCVVersionError{}):
 		return true
-	case errIncompatibleMongodVersion:
+	case errors.Is(err, incompatibleMongodVersionError{}):
 		if bcp.Type == pbm.LogicalBackup {
 			return true
 		}
@@ -770,11 +773,13 @@ func isValidBaseSnapshot(bcp *pbm.BackupMeta) bool {
 	return false
 }
 
-func getBackupSize(bcp *pbm.BackupMeta, stg storage.Storage) (s int64, err error) {
+func getBackupSize(bcp *pbm.BackupMeta, stg storage.Storage) (int64, error) {
 	if bcp.Size > 0 {
 		return bcp.Size, nil
 	}
 
+	var s int64
+	var err error
 	switch bcp.Status {
 	case pbm.StatusDone, pbm.StatusCancelled, pbm.StatusError:
 		s, err = getLegacySnapshotSize(bcp, stg)
@@ -787,12 +792,12 @@ func getBackupSize(bcp *pbm.BackupMeta, stg storage.Storage) (s int64, err error
 	return s, err
 }
 
-func getLegacySnapshotSize(bcp *pbm.BackupMeta, stg storage.Storage) (s int64, err error) {
+func getLegacySnapshotSize(bcp *pbm.BackupMeta, stg storage.Storage) (int64, error) {
 	switch bcp.Type {
 	case pbm.LogicalBackup:
 		return getLegacyLogicalSize(bcp, stg)
 	case pbm.PhysicalBackup, pbm.IncrementalBackup:
-		return getLegacyPhysSize(bcp.Replsets, stg)
+		return getLegacyPhysSize(bcp.Replsets)
 	case pbm.ExternalBackup:
 		return 0, nil
 	default:
@@ -800,7 +805,8 @@ func getLegacySnapshotSize(bcp *pbm.BackupMeta, stg storage.Storage) (s int64, e
 	}
 }
 
-func getLegacyPhysSize(rsets []pbm.BackupReplset, stg storage.Storage) (s int64, err error) {
+func getLegacyPhysSize(rsets []pbm.BackupReplset) (int64, error) {
+	var s int64
 	for _, rs := range rsets {
 		for _, f := range rs.Files {
 			s += f.StgSize
@@ -812,7 +818,9 @@ func getLegacyPhysSize(rsets []pbm.BackupReplset, stg storage.Storage) (s int64,
 
 var errMissedFile = errors.New("missed file")
 
-func getLegacyLogicalSize(bcp *pbm.BackupMeta, stg storage.Storage) (s int64, err error) {
+func getLegacyLogicalSize(bcp *pbm.BackupMeta, stg storage.Storage) (int64, error) {
+	var s int64
+	var err error
 	for _, rs := range bcp.Replsets {
 		ds, er := stg.FileStat(rs.DumpName)
 		if er != nil {
