@@ -127,7 +127,8 @@ func (c *Ctl) List() (*ListOut, error) {
 	if err != nil {
 		return nil, errors.Wrap(err, "run pbm list -o json")
 	}
-	l := new(ListOut)
+
+	l := &ListOut{}
 	err = json.Unmarshal(skipCtl(o), l)
 	if err != nil {
 		return nil, errors.Wrap(err, "unmarshal list")
@@ -295,7 +296,7 @@ func (c *Ctl) RunCmd(cmds ...string) (string, error) {
 		return "", errors.Wrap(err, "ContainerExecCreate")
 	}
 
-	container, err := c.cn.ContainerExecAttach(c.ctx, id.ID, execConf)
+	container, err := c.cn.ContainerExecAttach(c.ctx, id.ID, types.ExecStartCheck{})
 	if err != nil {
 		return "", errors.Wrap(err, "attach to failed container")
 	}
