@@ -3,11 +3,11 @@ package sharded
 import (
 	"log"
 
-	"github.com/percona/percona-backup-mongodb/e2e-tests/pkg/pbm"
-	pbmt "github.com/percona/percona-backup-mongodb/pbm"
+	pbmt "github.com/percona/percona-backup-mongodb/e2e-tests/pkg/pbm"
+	"github.com/percona/percona-backup-mongodb/pbm"
 )
 
-func (c *Cluster) ClockSkew(typ pbmt.BackupType, mongoVersion string) {
+func (c *Cluster) ClockSkew(typ pbm.BackupType, mongoVersion string) {
 	timeShifts := []string{
 		"+90m", "-195m", "+2d", "-7h", "+11m", "+42d", "-13h",
 	}
@@ -18,11 +18,11 @@ func (c *Cluster) ClockSkew(typ pbmt.BackupType, mongoVersion string) {
 
 	for k, rs := range rsNames {
 		if k >= len(timeShifts) {
-			k = k % len(timeShifts)
+			k %= len(timeShifts)
 		}
 		shift := timeShifts[k]
 
-		err := pbm.ClockSkew(rs, shift, c.cfg.DockerURI)
+		err := pbmt.ClockSkew(rs, shift, c.cfg.DockerURI)
 		if err != nil {
 			log.Fatalf("ERROR: clock skew for %v: %v\n", rs, err)
 		}
