@@ -6,8 +6,6 @@ import (
 
 	"github.com/golang/snappy"
 	"github.com/mongodb/mongo-tools/common/idx"
-	mlog "github.com/mongodb/mongo-tools/common/log"
-	"github.com/mongodb/mongo-tools/common/options"
 	"github.com/pkg/errors"
 	"go.mongodb.org/mongo-driver/bson/primitive"
 	"go.mongodb.org/mongo-driver/mongo"
@@ -19,17 +17,6 @@ import (
 	"github.com/percona/percona-backup-mongodb/pbm/storage"
 )
 
-func init() {
-	// set date format for mongo tools (mongodump/mongorestore) logger
-	//
-	// duplicated in backup/restore packages just
-	// in the sake of clarity
-	mlog.SetDateFormat(log.LogTimeFormat)
-	mlog.SetVerbosity(&options.Verbosity{
-		VLevel: mlog.DebugLow,
-	})
-}
-
 func GetMetaFromStore(stg storage.Storage, bcpName string) (*pbm.BackupMeta, error) {
 	rd, err := stg.SourceReader(bcpName + pbm.MetadataFileSuffix)
 	if err != nil {
@@ -43,48 +30,56 @@ func GetMetaFromStore(stg storage.Storage, bcpName string) (*pbm.BackupMeta, err
 	return b, errors.Wrap(err, "decode")
 }
 
-func toState(cn *pbm.PBM, status pbm.Status, bcp string, inf *pbm.NodeInfo, reconcileFn reconcileStatus, wait *time.Duration) (meta *pbm.RestoreMeta, err error) {
-	err = cn.ChangeRestoreRSState(bcp, inf.SetName, status, "")
+func toState(
+	cn *pbm.PBM,
+	status pbm.Status,
+	bcp string,
+	inf *pbm.NodeInfo,
+	reconcileFn reconcileStatus,
+	wait *time.Duration,
+) error {
+	err := cn.ChangeRestoreRSState(bcp, inf.SetName, status, "")
 	if err != nil {
-		return nil, errors.Wrap(err, "set shard's status")
+		return errors.Wrap(err, "set shard's status")
 	}
 
 	if inf.IsLeader() {
-		meta, err = reconcileFn(status, wait)
+		err = reconcileFn(status, wait)
 		if err != nil {
-			if errors.Cause(err) == errConvergeTimeOut {
-				return nil, errors.Wrap(err, "couldn't get response from all shards")
+			if errors.Is(err, errConvergeTimeOut) {
+				return errors.Wrap(err, "couldn't get response from all shards")
 			}
-			return nil, errors.Wrapf(err, "check cluster for restore `%s`", status)
+			return errors.Wrapf(err, "check cluster for restore `%s`", status)
 		}
 	}
 
 	err = waitForStatus(cn, bcp, status)
 	if err != nil {
-		return nil, errors.Wrapf(err, "waiting for %s", status)
+		return errors.Wrapf(err, "waiting for %s", status)
 	}
 
-	return meta, nil
+	return nil
 }
 
-type reconcileStatus func(status pbm.Status, timeout *time.Duration) (*pbm.RestoreMeta, error)
+type reconcileStatus func(status pbm.Status, timeout *time.Duration) error
 
 // convergeCluster waits until all participating shards reached `status` and updates a cluster status
-func convergeCluster(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.Status) (*pbm.RestoreMeta, error) {
+func convergeCluster(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.Status) error {
 	tk := time.NewTicker(time.Second * 1)
 	defer tk.Stop()
+
 	for {
 		select {
 		case <-tk.C:
-			ok, meta, err := converged(cn, name, opid, shards, status)
+			ok, err := converged(cn, name, opid, shards, status)
 			if err != nil {
-				return meta, err
+				return err
 			}
 			if ok {
-				return meta, nil
+				return nil
 			}
 		case <-cn.Context().Done():
-			return nil, nil
+			return nil
 		}
 	}
 }
@@ -93,40 +88,49 @@ var errConvergeTimeOut = errors.New("reached converge timeout")
 
 // convergeClusterWithTimeout waits up to the geiven timeout until all participating shards reached
 // `status` and then updates the cluster status
-func convergeClusterWithTimeout(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.Status, t time.Duration) (meta *pbm.RestoreMeta, err error) {
+func convergeClusterWithTimeout(
+	cn *pbm.PBM,
+	name,
+	opid string,
+	shards []pbm.Shard,
+	status pbm.Status,
+	t time.Duration,
+) error {
 	tk := time.NewTicker(time.Second * 1)
 	defer tk.Stop()
+
 	tout := time.NewTicker(t)
 	defer tout.Stop()
+
 	for {
 		select {
 		case <-tk.C:
 			var ok bool
-			ok, meta, err = converged(cn, name, opid, shards, status)
+			ok, err := converged(cn, name, opid, shards, status)
 			if err != nil {
-				return meta, err
+				return err
 			}
 			if ok {
-				return meta, nil
+				return nil
 			}
 		case <-tout.C:
-			return meta, errConvergeTimeOut
+			return errConvergeTimeOut
 		case <-cn.Context().Done():
-			return nil, nil
+			return nil
 		}
 	}
 }
 
-func converged(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.Status) (bool, *pbm.RestoreMeta, error) {
+func converged(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.Status) (bool, error) {
 	shardsToFinish := len(shards)
 	bmeta, err := cn.GetRestoreMeta(name)
 	if err != nil {
-		return false, nil, errors.Wrap(err, "get backup metadata")
+		return false, errors.Wrap(err, "get backup metadata")
 	}
 
 	clusterTime, err := cn.ClusterTime()
 	if err != nil {
-		return false, nil, errors.Wrap(err, "read cluster time")
+		return false, errors.Wrap(err, "read cluster time")
 	}
 
 	for _, sh := range shards {
@@ -141,12 +145,12 @@ func converged(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.St
 
 				// nodes are cleaning its locks moving to the done status
 				// so no lock is ok and not need to ckech the heartbeats
-				if status != pbm.StatusDone && err != mongo.ErrNoDocuments {
+				if status != pbm.StatusDone && !errors.Is(err, mongo.ErrNoDocuments) {
 					if err != nil {
-						return false, nil, errors.Wrapf(err, "unable to read lock for shard %s", shard.Name)
+						return false, errors.Wrapf(err, "unable to read lock for shard %s", shard.Name)
 					}
 					if lock.Heartbeat.T+pbm.StaleFrameSec < clusterTime.T {
-						return false, nil, errors.Errorf("lost shard %s, last beat ts: %d", shard.Name, lock.Heartbeat.T)
+						return false, errors.Errorf("lost shard %s, last beat ts: %d", shard.Name, lock.Heartbeat.T)
 					}
 				}
 
@@ -157,7 +161,7 @@ func converged(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.St
 				case pbm.StatusError:
 					bmeta.Status = pbm.StatusError
 					bmeta.Error = shard.Error
-					return false, nil, errors.Errorf("restore on the shard %s failed with: %s", shard.Name, shard.Error)
+					return false, errors.Errorf("restore on the shard %s failed with: %s", shard.Name, shard.Error)
 				}
 			}
 		}
@@ -166,17 +170,18 @@ func converged(cn *pbm.PBM, name, opid string, shards []pbm.Shard, status pbm.St
 	if shardsToFinish == 0 {
 		err := cn.ChangeRestoreState(name, status, "")
 		if err != nil {
-			return false, nil, errors.Wrapf(err, "update backup meta with %s", status)
+			return false, errors.Wrapf(err, "update backup meta with %s", status)
 		}
-		return true, bmeta, nil
+		return true, nil
 	}
 
-	return false, bmeta, nil
+	return false, nil
 }
 
 func waitForStatus(cn *pbm.PBM, name string, status pbm.Status) error {
 	tk := time.NewTicker(time.Second * 1)
 	defer tk.Stop()
+
 	for {
 		select {
 		case <-tk.C:
@@ -209,33 +214,17 @@ func waitForStatus(cn *pbm.PBM, name string, status pbm.Status) error {
 	}
 }
 
-func GetBaseBackup(cn *pbm.PBM, bcpName string, tsTo primitive.Timestamp, stg storage.Storage) (bcp *pbm.BackupMeta, err error) {
-	if bcpName == "" {
-		bcp, err = cn.GetLastBackup(&tsTo)
-		if errors.Is(err, pbm.ErrNotFound) {
-			return nil, errors.Errorf("no backup found before ts %v", tsTo)
-		}
-		if err != nil {
-			return nil, errors.Wrap(err, "define last backup")
-		}
-		return bcp, nil
-	}
-
-	bcp, err = SnapshotMeta(cn, bcpName, stg)
-	if err != nil {
-		return nil, err
-	}
-	if primitive.CompareTimestamp(bcp.LastWriteTS, tsTo) >= 0 {
-		return nil, errors.New("snapshot's last write is later than the target time. Try to set an earlier snapshot. Or leave the snapshot empty so PBM will choose one.")
-	}
-
-	return bcp, nil
-}
-
 // chunks defines chunks of oplog slice in given range, ensures its integrity (timeline
 // is contiguous - there are no gaps), checks for respective files on storage and returns
 // chunks list if all checks passed
-func chunks(cn *pbm.PBM, stg storage.Storage, from, to primitive.Timestamp, rsName string, rsMap map[string]string) ([]pbm.OplogChunk, error) {
+func chunks(
+	cn *pbm.PBM,
+	stg storage.Storage,
+	from,
+	to primitive.Timestamp,
+	rsName string,
+	rsMap map[string]string,
+) ([]pbm.OplogChunk, error) {
 	mapRevRS := pbm.MakeReverseRSMapFunc(rsMap)
 	chunks, err := cn.PITRGetChunksSlice(mapRevRS(rsName), from, to)
 	if err != nil {
@@ -247,19 +236,25 @@ func chunks(cn *pbm.PBM, stg storage.Storage, from, to primitive.Timestamp, rsNa
 	}
 
 	if primitive.CompareTimestamp(chunks[len(chunks)-1].EndTS, to) == -1 {
-		return nil, errors.Errorf("no chunk with the target time, the last chunk ends on %v", chunks[len(chunks)-1].EndTS)
+		return nil, errors.Errorf(
+			"no chunk with the target time, the last chunk ends on %v",
+			chunks[len(chunks)-1].EndTS)
 	}
 
 	last := from
 	for _, c := range chunks {
 		if primitive.CompareTimestamp(last, c.StartTS) == -1 {
-			return nil, errors.Errorf("integrity vilolated, expect chunk with start_ts %v, but got %v", last, c.StartTS)
+			return nil, errors.Errorf(
+				"integrity vilolated, expect chunk with start_ts %v, but got %v",
+				last, c.StartTS)
 		}
 		last = c.EndTS
 
 		_, err := stg.FileStat(c.FName)
 		if err != nil {
-			return nil, errors.Errorf("failed to ensure chunk %v.%v on the storage, file: %s, error: %v", c.StartTS, c.EndTS, c.FName, err)
+			return nil, errors.Errorf(
+				"failed to ensure chunk %v.%v on the storage, file: %s, error: %v",
+				c.StartTS, c.EndTS, c.FName, err)
 		}
 	}
 
@@ -274,8 +269,10 @@ type applyOplogOption struct {
 	filter oplog.OpFilter
 }
 
-type setcommittedTxnFn func(txn []pbm.RestoreTxn) error
-type getcommittedTxnFn func() (map[string]primitive.Timestamp, error)
+type (
+	setcommittedTxnFn func(txn []pbm.RestoreTxn) error
+	getcommittedTxnFn func() (map[string]primitive.Timestamp, error)
+)
 
 // By looking at just transactions in the oplog we can't tell which shards
 // were participating in it. But we can assume that if there is
@@ -298,9 +295,12 @@ type getcommittedTxnFn func() (map[string]primitive.Timestamp, error)
 // messages. So it might happen that one shard committed the txn but another has
 // observed not all prepared messages by the end of the oplog. In such a case we
 // should report it in logs and describe-restore.
+//
+//nolint:nonamedreturns
 func applyOplog(node *mongo.Client, chunks []pbm.OplogChunk, options *applyOplogOption, sharded bool,
 	ic *idx.IndexCatalog, setTxn setcommittedTxnFn, getTxn getcommittedTxnFn, stat *pbm.DistTxnStat,
-	mgoV *pbm.MongoVersion, stg storage.Storage, log *log.Event) (partial []oplog.Txn, err error) {
+	mgoV *pbm.MongoVersion, stg storage.Storage, log *log.Event,
+) (partial []oplog.Txn, err error) {
 	log.Info("starting oplog replay")
 
 	var (
@@ -380,20 +380,26 @@ func applyOplog(node *mongo.Client, chunks []pbm.OplogChunk, options *applyOplog
 	return partial, nil
 }
 
-func replayChunk(file string, oplog *oplog.OplogRestore, stg storage.Storage, c compress.CompressionType) (lts primitive.Timestamp, err error) {
+func replayChunk(
+	file string,
+	oplog *oplog.OplogRestore,
+	stg storage.Storage,
+	c compress.CompressionType,
+) (primitive.Timestamp, error) {
 	or, err := stg.SourceReader(file)
 	if err != nil {
+		lts := primitive.Timestamp{}
 		return lts, errors.Wrapf(err, "get object %s form the storage", file)
 	}
 	defer or.Close()
 
 	oplogReader, err := compress.Decompress(or, c)
 	if err != nil {
+		lts := primitive.Timestamp{}
 		return lts, errors.Wrapf(err, "decompress object %s", file)
 	}
 	defer oplogReader.Close()
 
-	lts, err = oplog.Apply(oplogReader)
-
+	lts, err := oplog.Apply(oplogReader)
 	return lts, errors.Wrap(err, "apply oplog for chunk")
 }
